% ----------------------------------------------------
% COMMON SPECIFICATIONS
%-----------------------------------------------------
clear;clc;close all;
order=4;periods=10;cumperiod=8;
reps=100;
confidence1=0.9;
confidence2=0.68;
convert_to_levels=1;
% ----------------------------------------------------
% FIG 1: IMPACT AND CUMULATIVE WITH CONFIDENCE BANDS
%-----------------------------------------------------
samplestart=1960;
[date1,rgdp,rgov,inflyp,sr2,bondsb,lrate2,taxy,cc,gdebt_gdp,unemp,recession,ffr,...
    rcons,rinv,infle,news,gf,pop]=getdata(samplestart);

data1=[dlog(rgov,1) dlog(rgdp,1) trimr(taxy,1,0) dlev(gdebt_gdp,1)...
    trimr([inflyp sr2 bondsb-lrate2 cc./1000],1,0)];

    % check for missings
    if sum(sum(isnan(data1)))>0;error('missing observations, adjust sample!');end
    
bandwidth=sqrt(size(data1,1)); 

rposg=1;              %relative position of G-variable
rposy=2;              %relative position of Y-variable
selvek=(size(data1,2)*(rposg-1)+1:size(data1,2)*rposg)';
effectiveT=size(data1,1)-order;

% point estimates
 [~,IRF,Sigu,U,Pmat]=tvpvar(data1,order,periods,bandwidth);
% bootstrap data
 [bsdatamat]=tvpvar_bs2(data1,order,bandwidth,reps); 
 
[resp,resplower1,respupper1,resplower2,respupper2,impact,impactlower1,impactupper1,...
    impactlower2,impactupper2,average,averagelower1,averageupper1,averagelower2,averageupper2]=...
    get_impactaverage(IRF,bsdatamat,selvek,rposy,confidence1,confidence2,order,periods,bandwidth,...
    convert_to_levels,cumperiod);
    
figure(1)
subplot(1,2,1)
plot(date1(order+2:end)', impactlower1', 'k--');
hold on;
plot(date1(order+2:end)', impactupper1', 'k--');
hold on
x2 = [date1(order+2:end)', fliplr(date1(order+2:end)')];
inBetween = [impactupper2', fliplr(impactlower2')];
h=fill(x2, inBetween, [0.7 0.7 0.7]);
set(h,'EdgeColor','none');
hold on
plot(date1(order+2:end),impact,'k','LineWidth', 1.2)
hold on
plot(date1(order+2:end), zeros(effectiveT,1),'k:')
title('Impact Y response');
subplot(1,2,2)
plot(date1(order+2:end)', averagelower1', 'k--');
hold on;
plot(date1(order+2:end)', averageupper1', 'k--');
x2 = [date1(order+2:end)', fliplr(date1(order+2:end)')];
inBetween = [averageupper2', fliplr(averagelower2')];
h=fill(x2, inBetween, [0.7 0.7 0.7]);
set(h,'EdgeColor','none');
hold on
plot(date1(order+2:end),average,'k','LineWidth', 1.2)
hold on
plot(date1(order+2:end), zeros(effectiveT,1),'k:')
title('Average Y response');
