% ----------------------------------------------------
% COMMON SPECIFICATIONS
%-----------------------------------------------------
clear;clc;close all;
order=4;periods=16;cumperiod=8;
reps=1;
confidence1=0.90;
confidence2=0.68;
convert_to_levels=1;

% ----------------------------------------------------
% FIG 10: output responses during NBER recessions
%-----------------------------------------------------
samplestart=1960;
[date1,rgdp,rgov,inflyp,sr2,bondsb,lrate2,taxy,cc,gdebt_gdp,unemp,recession,ffr,...
    rcons,rinv,infle,news,gf,pop,ex,deficity]=getdata(samplestart);
data1=[dlog(rgov,1) dlog(rgdp,1) trimr(taxy,1,0) dlev(gdebt_gdp,1)  trimr([inflyp sr2 bondsb-lrate2 cc./1000],1,0)];
    % check for missings
    if sum(sum(isnan(data1)))>0;error('missing observations, adjust sample!');end   
bandwidth=sqrt(size(data1,1)); 

rposg=1;              %relative position of G-variable
rposy=2;              %relative position of Y-variable
selvek=(size(data1,2)*(rposg-1)+1:size(data1,2)*rposg)';
effectiveT=size(data1,1)-order;

effectivedate1=date1(order+2:end);
recession_shortened=recession(order+2:end);

recessiondates=[];counter=0;
for t=2:effectiveT
    if recession_shortened(t)==1 & recession_shortened(t-1)==0
        counter=counter+1;
        % recession begins
        recessiondates(counter,1)=effectivedate1(t);
    elseif recession_shortened(t)==0 & recession_shortened(t-1)==1
        %recession ends
        recessiondates(counter,2)=effectivedate1(t-1);
    end
end

% point estimates
 [~,IRF,~]=tvpvar(data1,order,periods,bandwidth);
% bootstrap data
 [bsdatamat]=tvpvar_bs2(data1,order,bandwidth,reps); 
 
[yresp,yresplower1,yrespupper1,yresplower2,yrespupper2,impact,impactlower1,impactupper1,...
    impactlower2,impactupper2,average,averagelower1,averageupper1,averagelower2,averageupper2]=...
    get_impactaverage(IRF,bsdatamat,selvek,rposy,confidence1,confidence2,order,periods,bandwidth,...
    convert_to_levels,cumperiod);
    
% constant coefs for comparison
[~,~,~,cpirfs]=constantcoefficientsvar(data1,order,periods);
cpy=cpirfs(:,selvek(rposy));cpg=cpirfs(:,selvek(rposg));
if convert_to_levels==1
    cpy=integrat2(cpy);cpg=integrat2(cpg);
end

maty=[];matlower=[];matupper=[];
for i=1:size(recessiondates,1)
    begindate=find(effectivedate1==recessiondates(i,1));
    enddate=find(effectivedate1==recessiondates(i,2));
    thisy=mean(yresp(:,begindate:enddate),2);
    thislower=mean(yresplower1(:,begindate:enddate),2);
    thisupper=mean(yrespupper1(:,begindate:enddate),2);
    maty=[maty thisy];
    matlower=[matlower thislower];
    matupper=[matupper thisupper];
end

figure;
subplot(1,2,1)
plot(cpy,'LineWidth', 1.2)
hold on
plot(maty(:,1),'--','LineWidth', 1.2)
hold on
plot(maty(:,2),':','LineWidth', 1.2)
hold on
plot(maty(:,3),'-.','LineWidth', 1.2)
legend('CP','70q1-70q4','73q4-75q1','80q1-80q3','Location','northwest','Orientation','vertical')
ylim([-0.6 2.1])
title('1970-1980')
subplot(1,2,2)
plot(cpy,'LineWidth', 1.2)
hold on
plot(maty(:,4),'--','LineWidth', 1.2)
hold on
plot(maty(:,5),':','LineWidth', 1.2)
hold on
plot(maty(:,6),'-.','LineWidth', 1.2)
hold on
plot(maty(:,7),'-o','LineWidth', 1.2)
legend('CP','81q3-82q4','90q3-91q1','01q2-01q4','08q1-09q2','Location','northwest','Orientation','vertical')
title('1981-2009')
ylim([-0.6 2.1])

