% ----------------------------------------------------
% COMMON SPECIFICATIONS
%-----------------------------------------------------
clear;clc;close all;
order=4;periods=10;cumperiod=8;
reps=100;confidence=0.90;
convert_to_levels=1;
% ----------------------------------------------------
% FIG 2: Y response, G response, cumulative multiplier
%-----------------------------------------------------
samplestart=1960;
[date1,rgdp,rgov,inflyp,sr2,bondsb,lrate2,taxy,cc,gdebt_gdp,unemp,recession,ffr,...
    rcons,rinv,infle,news,gf,pop]=getdata(samplestart);

data1=[dlog(rgov,1) dlog(rgdp,1) trimr(taxy,1,0) dlev(gdebt_gdp,1)  trimr([inflyp sr2 bondsb-lrate2 cc./1000],1,0)];

    % check for missings
    if sum(sum(isnan(data1)))>0;error('missing observations, adjust sample!');end
    
bandwidth=sqrt(size(data1,1)); 
rposg=1;              %relative position of G-variable
rposy=2;              %relative position of Y-variable
selvek=(size(data1,2)*(rposg-1)+1:size(data1,2)*rposg)';
effectiveT=size(data1,1)-order;

% point estimates
 [~,IRF,~]=tvpvar(data1,order,periods,bandwidth);
 
yresp=squeeze(IRF(:,selvek(rposy),:));
gresp=squeeze(IRF(:,selvek(rposg),:));
if convert_to_levels==1
   yresp=integrat2(yresp);
   gresp=integrat2(gresp);
end
ycum=cumsum(yresp);
gcum=cumsum(gresp);
cmult=cumsum(yresp)./cumsum(gresp);
  
figure; 
plot(date1(order+2:end),ycum(cumperiod,:)'/cumperiod,'LineWidth', 1.2)
hold on
plot(date1(order+2:end), gcum(cumperiod,:)'/cumperiod,'--','LineWidth', 1.2)
hold on
plot(date1(order+2:end), cmult(cumperiod,:)','-.','LineWidth', 1.2)
hold on
plot(date1(order+2:end), zeros(effectiveT,1),':','LineWidth', 1.2)
legend('Average Y response','Average G response','Cumulative multiplier','Location','northwest','Orientation','vertical')

