% ----------------------------------------------------
% COMMON SPECIFICATIONS
%-----------------------------------------------------
clear;clc;close all;
order=4;periods=10;cumperiod=8;
reps=100;
confidence1=0.9;
confidence2=0.68;
convert_to_levels=1;

% ----------------------------------------------------
% FIG 4: Baseline, forecasts, news
%-----------------------------------------------------
% baseline first
samplestart=1960;
[date1,rgdp,rgov,inflyp,sr2,bondsb,lrate2,taxy,cc,gdebt_gdp,unemp,recession,ffr,...
    rcons,rinv,infle,news,gf,pop]=KL_getdata(samplestart);

data1=[dlog(rgov,1) dlog(rgdp,1) trimr(taxy,1,0) dlev(gdebt_gdp,1)  trimr([inflyp sr2 bondsb-lrate2 cc./1000],1,0)];

    % check for missings
    if sum(sum(isnan(data1)))>0;error('missing observations, adjust sample!');end   
    
bandwidth=sqrt(size(data1,1)); 

rposg=1;              %relative position of G-variable
rposy=2;              %relative position of Y-variable
selvek=(size(data1,2)*(rposg-1)+1:size(data1,2)*rposg)';
effectiveT=size(data1,1)-order;

% point estimates
 [~,IRF1,~,U1]=tvpvar(data1,order,periods,bandwidth);
% bootstrap data
 [bsdatamat1]=tvpvar_bs2(data1,order,bandwidth,reps); 

[resp,resplower1,respupper1,resplower2,respupper2,impact,impactlower1,impactupper1,...
    impactlower2,impactupper2,average,averagelower1,averageupper1,averagelowe2,averageupper2]=...
    get_impactaverage(IRF1,bsdatamat1,selvek,rposy,confidence1,confidence2,order,periods,bandwidth,...
    convert_to_levels,cumperiod);

yresp1=resp;
impact1=impact;impactlowerbase=impactlower1;impactupperbase=impactupper1;
average1=average;averagelowerbase=averagelower1;averageupperbase=averageupper1;


% forecasts
samplestart=1966.75;
[date2,rgdp,rgov,inflyp,sr2,bondsb,lrate2,taxy,cc,gdebt_gdp,unemp,recession,ffr,...
    rcons,rinv,infle,news,gf,pop]=KL_getdata(samplestart);

data2=[gf trimr(data1,size(data1,1)-length(date2),0)];
    % check for missings
    if sum(sum(isnan(data2)))>0;error('missing observations, adjust sample!');end
    
rposg=2;              %relative position of G-variable
rposy=3;              %relative position of Y-variable
selvek=(size(data2,2)*(rposg-1)+1:size(data2,2)*rposg)';

% point estimates
 [~,IRF2,~,U2]=tvpvar(data2,order,periods,bandwidth);
% bootstrap data
 [bsdatamat2]=tvpvar_bs2(data2,order,bandwidth,reps); 
% get responses
 
[resp,resplower1,respupper1,resplower2,respupper2,impact,impactlower1,impactupper1,...
    impactlower2,impactupper2,average,averagelower1,averageupper1,averagelower2,averageupper2]=...
    get_impactaverage(IRF2,bsdatamat2,selvek,rposy,confidence1,confidence2,order,periods,bandwidth,...
    convert_to_levels,cumperiod);

yresp2=resp;
impact2=impact;
average2=average;
 
% news
data3=[news trimr(data1,size(data1,1)-length(date2),0)];

    % check for missings
    if sum(sum(isnan(data3)))>0;error('missing observations, adjust sample!');end
    
rposg=2;              %relative position of G-variable
rposy=3;              %relative position of Y-variable
selvek=(size(data3,2)*(rposg-1)+1:size(data3,2)*rposg)';

% point estimates
 [~,IRF3,~,U3]=tvpvar(data3,order,periods,bandwidth);
% bootstrap data
 [bsdatamat3]=tvpvar_bs2(data3,order,bandwidth,reps); 
% get responses
 
 [resp,resplower1,respupper1,resplower2,respupper2,impact,impactlower1,impactupper1,...
    impactlower2,impactupper2,average,averagelower1,averageupper1,averagelower2,averageupper2]=...
    get_impactaverage(IRF3,bsdatamat3,selvek,rposy,confidence1,confidence2,order,periods,bandwidth,...
    convert_to_levels,cumperiod);

yresp3=resp;
impact3=impact;
average3=average;

cut=size(impact1,1)-size(impact2,1);

figure;
subplot(2,1,1);
    plot(date2(order+1:end), trimr(impact1,cut,0),'k','LineWidth', 1.2)
    hold on
    plot(date2(order+1:end), impact2,':','LineWidth', 1.2)
    hold on
    plot(date2(order+1:end), impact3,'-.','LineWidth', 1.2)
    hold on
    plot(date2(order+1:end),trimr(impactlowerbase,cut,0),'k--')
    hold on
    plot(date2(order+1:end),trimr(impactupperbase,cut,0),'k--')
    title('Impact Y response');
subplot(2,1,2);
    plot(date2(order+1:end), trimr(average1,cut,0),'k','LineWidth',1.2)
    hold on
    plot(date2(order+1:end), average2,':','LineWidth', 1.2)
    hold on
    plot(date2(order+1:end), average3,'-.','LineWidth', 1.2)
    hold on
    plot(date2(order+1:end), trimr(averagelowerbase,cut,0),'k--')
    hold on
    plot(date2(order+1:end), trimr(averageupperbase,cut,0),'k--')
    title('Average Y response');
    legend('Baseline','G-Forecast','Ramey News','Location','northwest','Orientation','vertical');
   
    
    