% ----------------------------------------------------
% COMMON SPECIFICATIONS
%-----------------------------------------------------
clear;clc;close all;
order=4;periods=8;cumperiod=8;
convert_to_levels=1;

% -------------------------------------------------------------
% FIG 4: timing of results
%--------------------------------------------------------------
samplestart=1960;
[date1,rgdp,rgov,inflyp,sr2,bondsb,lrate2,taxy,cc,gdebt_gdp,unemp,recession,ffr,...
    rcons,rinv,infle,news,gf,pop]=getdata(samplestart);
data1=[dlog(rgov,1) dlog(rgdp,1) trimr(taxy,1,0) dlev(gdebt_gdp,1)...
   trimr([inflyp sr2 bondsb-lrate2 cc./1000],1,0)];    
date1=date1(2:end);

% rolling sample endpoint 
bandwidth=2*sqrt(size(date1,1)-order-1); % double bandwidth to counter the shrinking kernel width at endpoint
amat1=[];dd=[];
for sampleend=2000:0.25:2015.75
    dd=[dd; sampleend];
    disp(num2str(sampleend));
    shortdata=data1(1:find(date1==sampleend),:);
    rposg=1;              %relative position of G-variable
    rposy=2;              %relative position of Y-variable
    selvek=(size(shortdata,2)*(rposg-1)+1:size(shortdata,2)*rposg)';
    % point estimates
     [~,IRF,Sigu,U,Pmat]=tvpvar(shortdata,order,periods,bandwidth);
    resp=squeeze(IRF(:,selvek(rposy),:));
    if convert_to_levels==1
       resp=integrat2(resp);
    end
    cum=cumsum(resp);
    average=cum(cumperiod,:)'/cumperiod; 
    amat1=[amat1 ; [sampleend average(end)]];
end

% breakpoint VAR
samplestart=1960;
[date1,rgdp,rgov,inflyp,sr2,bondsb,lrate2,taxy,cc,gdebt_gdp,unemp,recession,ffr,...
    rcons,rinv,infle,news,gf,pop]=getdata(samplestart);
data=[dlog(rgov,1) dlog(rgdp,1) trimr(taxy,1,0) trimr(sr2,1,0) trimr(bondsb-lrate2,1,0)];
date1=date1(2:end);
k=size(data,2);T=size(data,1);
amat2=[];
for breakt=2000:0.25:2009.25
    dd=[dd;breakt];
    breakpoint=find(date1==breakt);
    I=[zeros(breakpoint-1,1);ones(T-breakpoint+1,1)];
    Iorder=trimr(I,order,0);
    exogmat=[Iorder (1-Iorder)];
    rhs=exogmat;
    for j=1:order % for before-break coefs
        rhs=[rhs data(order+1-j:end-j,:)];
    end
    for j=1:order % for after-break coefs
        rhs=[rhs (Iorder).*data(order+1-j:end-j,:)];
    end
    u=[];
    coefmat=[];
    for i=1:k
            lhs=data(order+1:end,i);
            thisb=(rhs'*rhs)\(rhs'*lhs);
            thisu=lhs-rhs*thisb;
            u=[u thisu];
            coefmat=[coefmat; thisb'];        
    end
    exogcoef=coefmat(:,1:size(exogmat,2));     %the coefficients of the exogs
    aa=coefmat(:,size(exogmat,2)+1:end);       %all other coefficients
    % reorganize aa as three dimensional array where sheet j is the 
    % matrix A_j with the coefficients pertaining to the j-th lag
    % coefs1 are the coefficients befor the break, coefs2 the ones after
    aa1=aa(:,1:k*order);
    aa2=aa(:,k*order+1:end);
    coefs=zeros(k,k,order);
    for j=1:order
        coefs(:,:,j)=aa1(:,j*k-k+1:j*k)+aa2(:,j*k-k+1:j*k);
    end
    % compute phi-matrices of VMA representation which contain impulse
    % response coefficients
        phimat=zeros(k,k,periods);
        phimat(:,:,1)=eye(k);
        for i=1:periods
            for j=1:i-1
                if j<=order
                   Aj=coefs(:,:,j);
                else
                   Aj=zeros(k,k);
                end    
                phimat(:,:,i)=phimat(:,:,i)+Aj*phimat(:,:,i-j);
            end
        end
    % generate recursively identified impulse responses to shocks of size 1
    u1=u(Iorder==0,:);
    u2=u(Iorder==1,:);
    sigu1=(u1'*u1)/(size(u1,1));
    sigu2=(u2'*u2)/(size(u2,1));
    pmat1=chol(sigu1);pmat1=pmat1';      
    dmat1=diag(diag(pmat1),0);wmat1=pmat1*inv(dmat1); % use wmat for irfs of one unit size
    pmat2=chol(sigu2);pmat2=pmat2';      
    dmat2=diag(diag(pmat2),0);wmat2=pmat2*inv(dmat2); % use wmat for irfs of one unit size
    irfs=[];
    for i=1:periods
            phi_chol=phimat(:,:,i)*wmat2;
            irfs=[irfs; phi_chol(:)'];  
    end    
    amat2=[amat2;[breakt mean(integrat2(irfs(1:periods,2)))]];
end

figure;
subplot(1,2,1);
plot(amat1(:,1),amat1(:,2),'k-','LineWidth', 1.2);
xlim([1999.5 2016]);
ylim([-0.1 1]);
title({'recursive estimation,'; 'varying sample end'})
xlabel('Sample ends in T^*=...');
subplot(1,2,2);
plot(amat2(:,1),amat2(:,2),'k-','LineWidth', 1.2);
xlim([1999.5 2009.25]);
ylim([-0.1 1]);
title({'VAR with single'; 'parameter break'})
xlabel('Single break is in t^*=...');