% ----------------------------------------------------
% COMMON SPECIFICATIONS
%-----------------------------------------------------
clear;clc;close all;
order=4;periods=10;cumperiod=8;
reps=100;
confidence1=0.90;
confidence2=0.68;

% ----------------------------------------------------
% FIG7: spread response
%-----------------------------------------------------
samplestart=1969;
[date1,rgdp,rgov,inflyp,sr2,bondsb,lrate2,taxy,cc,gdebt_gdp,unemp,recession,ffr,...
    rcons,rinv,infle,news,gf,pop]=getdata(samplestart);

data1=[dlog(rgov,1) dlog(rgdp,1) trimr(taxy,1,0) dlev(gdebt_gdp,1) ...
    trimr([inflyp infle sr2 bondsb-lrate2 cc./1000],1,0)];

    % check for missings
    if sum(sum(isnan(data1)))>0;error('missing observations, adjust sample!');end
    
bandwidth=sqrt(size(data1,1)); 

rposg=1;              %relative position of G-variable
rposy=2;              %relative position of Y-variable
rposspread=8;
selvek=(size(data1,2)*(rposg-1)+1:size(data1,2)*rposg)';
effectiveT=size(data1,1)-order;

% point estimates
 [~,IRF,~]=tvpvar(data1,order,periods,bandwidth);
% bootstrap data
 [bsdatamat]=tvpvar_bs2(data1,order,bandwidth,reps); 
    
convert_to_levels=0; 
 [resp,resplower1,respupper1,resplower2,respupper2,impact,impactlower1,impactupper1,...
    impactlower2,impactupper2,average,averagelower1,averageupper1,averagelower2,averageupper2]=...
    get_impactaverage(IRF,bsdatamat,selvek,rposspread,confidence1,confidence2,order,periods,bandwidth,...
    convert_to_levels,cumperiod);
baanom=average;
baanomupper1=averageupper1;
baanomlower1=averagelower1;
baanomupper2=averageupper2;
baanomlower2=averagelower2;

figure;
plot(date1(order+2:end)', baanomlower1', 'k--');
xlim([1968 2017]);
hold on
plot(date1(order+2:end)', baanomupper1', 'k--');
hold on
x2 = [date1(order+2:end)', fliplr(date1(order+2:end)')];
inBetween = [baanomupper2', fliplr(baanomlower2')];
h=fill(x2, inBetween, [0.7 0.7 0.7]);
set(h,'EdgeColor','none');
hold on
plot(date1(order+2:end),baanom,'k','LineWidth', 1.2)
hold on
plot(date1(order+2:end), zeros(effectiveT,1),'k:')
title('Spread between corporate BAA and government bond yields, average');

