% ----------------------------------------------------
% COMMON SPECIFICATIONS
%-----------------------------------------------------
clear;clc;close all;
order=4;periods=10;cumperiod=8;
reps=100;
confidence1=0.90;
confidence2=0.68;

% -------------------------------------------------------
% FIG 8: investment, consumption, confidence
%--------------------------------------------------------

% first baseline data, use to find cc and debt responses
samplestart=1960;
[date,rgdp,rgov,inflyp,sr2,bondsb,lrate2,taxy,cc,gdebt_gdp,unemp,recession,ffr,...
    rcons,rinv,infle,news,gf,pop,ex,deficity]=getdata(samplestart);
data1=[dlog(rgov,1) dlog(rgdp,1) trimr(taxy,1,0) dlev(gdebt_gdp,1) ...
    trimr([inflyp sr2 bondsb-lrate2 cc./1000],1,0) ];
    % check for missings
    if sum(sum(isnan(data1)))>0;error('missing observations, adjust sample!');end
bandwidth=sqrt(size(data1,1)); 
rposg=1;              %relative position of G-variable
selvek=(size(data1,2)*(rposg-1)+1:size(data1,2)*rposg)';

% point estimates
 [~,IRF,~]=tvpvar(data1,order,periods,bandwidth);
% bootstrap data
 [bsdatamat]=tvpvar_bs2(data1,order,bandwidth,reps); 
    
% consumer confidence
convert_to_levels=0;
position=8;
 [resp,resplower1,respupper1,resplower2,respupper2,impact,impactlower1,impactupper1,...
    impactlower2,impactupper2,average,averagelower1,averageupper1,averagelower2,averageupper2]=...
    get_impactaverage(IRF,bsdatamat,selvek,position,confidence1,confidence2,order,periods,bandwidth,...
    convert_to_levels,cumperiod);
ccresp=average;
ccupper1=averageupper1;
cclower1=averagelower1;
ccupper2=averageupper2;
cclower2=averagelower2;

%debt
convert_to_levels=1;
position=4;
 [resp,resplower1,respupper1,resplower2,respupper2,impact,impactlower1,impactupper1,...
    impactlower2,impactupper2,average,averagelower1,averageupper1,averagelower2,averageupper2]=...
    get_impactaverage(IRF,bsdatamat,selvek,position,confidence1,confidence2,order,periods,bandwidth,...
    convert_to_levels,cumperiod);
debt=average;
debtupper1=averageupper1;
debtlower1=averagelower1;
debtupper2=averageupper2;
debtlower2=averagelower2;

% second: append either investment or consumption to baseline data
data2=[dlog(rgov,1) dlog(rgdp,1) trimr(taxy,1,0) dlev(gdebt_gdp,1) ...
    trimr([inflyp sr2 bondsb-lrate2 cc./1000],1,0) dlog(rinv,1)];
    % check for missings
    if sum(sum(isnan(data1)))>0;error('missing observations, adjust sample!');end
rposg=1;              %relative position of G-variable
selvek=(size(data2,2)*(rposg-1)+1:size(data2,2)*rposg)';

% point estimates
 [~,IRF,~]=tvpvar(data2,order,periods,bandwidth);
% bootstrap data
 [bsdatamat]=tvpvar_bs2(data2,order,bandwidth,reps); 
  
% investment
convert_to_levels=1;
rposinv=9;
 [resp,resplower1,respupper1,resplower2,respupper2,impact,impactlower1,impactupper1,...
    impactlower2,impactupper2,average,averagelower1,averageupper1,averagelower2,averageupper2]=...
    get_impactaverage(IRF,bsdatamat,selvek,rposinv,confidence1,confidence2,order,periods,bandwidth,...
    convert_to_levels,cumperiod);
inv=average;
invupper1=averageupper1;
invlower1=averagelower1;
invupper2=averageupper2;
invlower2=averagelower2;

% consumption
data3=[dlog(rgov,1) dlog(rgdp,1) trimr(taxy,1,0) dlev(gdebt_gdp,1) ...
    trimr([inflyp sr2 bondsb-lrate2 cc./1000],1,0) dlog(rcons,1)];

% point estimates
 [~,IRF,~]=tvpvar(data3,order,periods,bandwidth);
% bootstrap data
 [bsdatamat]=tvpvar_bs2(data3,order,bandwidth,reps); 

convert_to_levels=1;
rposc=9;
 [resp,resplower1,respupper1,resplower2,respupper2,impact,impactlower,impactupper,impactlower2,impactupper2,...
    average,averagelower1,averageupper1,averagelower2,averageupper2]=...
    get_impactaverage(IRF,bsdatamat,selvek,rposc,confidence1,confidence2,order,periods,bandwidth,...
    convert_to_levels,cumperiod);
cons=average;
consupper1=averageupper1;
conslower1=averagelower1;
consupper2=averageupper2;
conslower2=averagelower2;

% show figure
effectiveT=size(data1,1)-order;
figure;
subplot(1,3,1);
plot(date(order+2:end)', invlower1', 'k--');
hold on
plot(date(order+2:end)', invupper1', 'k--');
hold on
x2 = [date(order+2:end)', fliplr(date(order+2:end)')];
inBetween = [invupper2', fliplr(invlower2')];
h=fill(x2, inBetween, [0.7 0.7 0.7]);
set(h,'EdgeColor','none');
hold on
plot(date(order+2:end),inv,'k','LineWidth', 1.2)
hold on
plot(date(order+2:end), zeros(effectiveT,1),'k:')
xlim([date(order+2) date(end)])
title('Investment');
subplot(1,3,2);
plot(date(order+2:end)', conslower1', 'k--');
hold on
plot(date(order+2:end)', consupper1', 'k--');
hold on
x2 = [date(order+2:end)', fliplr(date(order+2:end)')];
inBetween = [consupper2', fliplr(conslower2')];
h=fill(x2, inBetween, [0.7 0.7 0.7]);
set(h,'EdgeColor','none');
hold on
plot(date(order+2:end),cons,'k','LineWidth', 1.2)
hold on
plot(date(order+2:end), zeros(effectiveT,1),'k:')
title('Consumption');
xlim([date(order+2) date(end)])
subplot(1,3,3);
plot(date(order+2:end)', cclower1', 'k--');
hold on
plot(date(order+2:end)', ccupper1', 'k--');
hold on
x2 = [date(order+2:end)', fliplr(date(order+2:end)')];
inBetween = [ccupper2', fliplr(cclower2')];
h=fill(x2, inBetween, [0.7 0.7 0.7]);
set(h,'EdgeColor','none');
hold on
plot(date(order+2:end),ccresp,'k','LineWidth', 1.2)
hold on
plot(date(order+2:end), zeros(effectiveT,1),'k:')
xlim([date(order+2) date(end)])
title('Consumer Confidence');


