% ----------------------------------------------------
% COMMON SPECIFICATIONS
%-----------------------------------------------------
clear;clc;close all;
order=4;periods=10;cumperiod=8;
reps=100;
confidence1=0.9;
confidence2=0.68;
% -------------------------------------------------------
% FIG 9: exchange rate, unemployment, debt, deficit
%--------------------------------------------------------
%first: baseline data, use to find debt responses
samplestart=1960;
[date,rgdp,rgov,inflyp,sr2,bondsb,lrate2,taxy,cc,gdebt_gdp,unemp,recession,ffr,...
    rcons,rinv,infle,news,gf,pop,ex,deficity]=getdata(samplestart);
data1=[dlog(rgov,1) dlog(rgdp,1) trimr(taxy,1,0) dlev(gdebt_gdp,1) ...
    trimr([inflyp sr2 bondsb-lrate2 cc./1000],1,0) ];
    % check for missings
    if sum(sum(isnan(data1)))>0;error('missing observations, adjust sample!');end
bandwidth=sqrt(size(data1,1)); 
rposg=1;              %relative position of G-variable
selvek=(size(data1,2)*(rposg-1)+1:size(data1,2)*rposg)';

% point estimates
 [~,IRF,~]=tvpvar(data1,order,periods,bandwidth);
% bootstrap data
 [bsdatamat]=tvpvar_bs2(data1,order,bandwidth,reps);

convert_to_levels=1;
position=4;
 [resp,resplower1,respupper1,resplower2,respupper2,impact,impactlower1,impactupper1,...
    impactlower2,impactupper2,average,averagelower1,averageupper1,averagelower2,averageupper2]=...
    get_impactaverage(IRF,bsdatamat,selvek,position,confidence1,confidence2,order,periods,bandwidth,...
    convert_to_levels,cumperiod);
debt=average;
debtupper1=averageupper1;
debtlower1=averagelower1;
debtupper2=averageupper2;
debtlower2=averagelower2;

% append unemployment to baseline data
samplestart=1960;
[date1,rgdp,rgov,inflyp,sr2,bondsb,lrate2,taxy,cc,gdebt_gdp,unemp,recession,ffr,...
    rcons,rinv,infle,news,gf,pop,ex,deficity]=getdata(samplestart);
data1=[dlog(rgov,1) dlog(rgdp,1) trimr(unemp,1,0) trimr(taxy,1,0)  dlev(gdebt_gdp,1)...
    trimr([inflyp sr2 bondsb-lrate2 cc./1000],1,0)];
    % check for missings
    if sum(sum(isnan(data1)))>0;error('missing observations, adjust sample!');end
rposg=1;              %relative position of G-variable
selvek=(size(data1,2)*(rposg-1)+1:size(data1,2)*rposg)';

% point estimates
 [~,IRF,Sigu,U,Pmat]=tvpvar(data1,order,periods,bandwidth);
% bootstrap data
 [bsdatamat]=tvpvar_bs2(data1,order,bandwidth,reps); 
 
convert_to_levels=0;
position=3;
[resp,resplower1,respupper1,resplower2,respupper2,impact,impactlower1,impactupper1,...
    impactlower2,impactupper2,average,averagelower1,averageupper1,averagelower2,averageupper2]=...
    get_impactaverage(IRF,bsdatamat,selvek,position,confidence1,confidence2,order,periods,bandwidth,...
    convert_to_levels,cumperiod);
urate=average;
urateupper1=averageupper1;
uratelower1=averagelower1;
urateupper2=averageupper2;
uratelower2=averagelower2;

% append fiscal deficit to baseline data
samplestart=1960;
[date1,rgdp,rgov,inflyp,sr2,bondsb,lrate2,taxy,cc,gdebt_gdp,unemp,recession,ffr,...
    rcons,rinv,infle,news,gf,pop,ex,deficity]=getdata(samplestart);
data1=[dlog(rgov,1) dlog(rgdp,1) dlog(taxy,1) dlev(gdebt_gdp,1), trimr(deficity,1,0),...
    trimr([inflyp sr2 bondsb-lrate2 cc./1000],1,0)];
    % check for missings
    if sum(sum(isnan(data1)))>0;error('missing observations, adjust sample!');end   
rposg=1;              %relative position of G-variable
%rpost=3;              %relative position of T-variable
selvek=(size(data1,2)*(rposg-1)+1:size(data1,2)*rposg)';
effectiveT=size(data1,1)-order;

% point estimates
 [~,IRF,~]=tvpvar(data1,order,periods,bandwidth);
% bootstrap data
 [bsdatamat]=tvpvar_bs2(data1,order,bandwidth,reps); 
 
convert_to_levels=1;
position=5;
 [resp,resplower1,respupper1,resplower2,respupper2,impact,impactlower1,impactupper1,...
    impactlower2,impactupper2,average,averagelower1,averageupper1,averagelower2,averageupper2]=...
    get_impactaverage(IRF,bsdatamat,selvek,position,confidence1,confidence2,order,periods,bandwidth,...
    convert_to_levels,cumperiod);
deficit=average;
deficitupper1=averageupper1;
deficitlower1=averagelower1;
deficitupper2=averageupper2;
deficitlower2=averagelower2;

% append exchange rate to baseline data
samplestart=1964;
[date4,rgdp,rgov,inflyp,sr2,bondsb,lrate2,taxy,cc,gdebt_gdp,unemp,recession,ffr,...
    rcons,rinv,infle,news,gf,pop,ex,deficity]=getdata(samplestart);
data1=[dlog(rgov,1) dlog(rgdp,1) trimr(taxy,1,0)  dlev(gdebt_gdp,1)...
    trimr([inflyp sr2 bondsb-lrate2 cc./1000],1,0) trimr(log(ex),1,0)];
    % check for missings
    if sum(sum(isnan(data1)))>0;error('missing observations, adjust sample!');end
rposg=1;              %relative position of G-variable
selvek=(size(data1,2)*(rposg-1)+1:size(data1,2)*rposg)';
effectiveTex=size(data1,1)-order;

% point estimates
 [~,IRF,Sigu,U,Pmat]=tvpvar(data1,order,periods,bandwidth);
% bootstrap data
 [bsdatamat]=tvpvar_bs2(data1,order,bandwidth,reps); 
 
convert_to_levels=0;
position=9;
[resp,resplower1,respupper1,resplower2,respupper2,impact,impactlower1,impactupper1,...
    impactlower2,impactupper2,average,averagelower1,averageupper1,averagelower2,averageupper2]=...
    get_impactaverage(IRF,bsdatamat,selvek,position,confidence1,confidence2,order,periods,bandwidth,...
    convert_to_levels,cumperiod);
exrate=average;
exrateupper1=averageupper1;
exratelower1=averagelower1;
exrateupper2=averageupper2;
exratelower2=averagelower2;

figure;
subplot(2,2,1);
plot(date4(order+2:end)', exratelower1', 'k--');
hold on
plot(date4(order+2:end)', exrateupper1', 'k--');
hold on
plot(date4(order+2:end), zeros(effectiveTex,1),'k:')
hold on
x2 = [date4(order+2:end)', fliplr(date4(order+2:end)')];
inBetween = [exrateupper2', fliplr(exratelower2')];
h=fill(x2, inBetween, [0.7 0.7 0.7]);
set(h,'EdgeColor','none');
hold on
plot(date4(order+2:end),exrate,'k','LineWidth', 1.2)
hold on
plot(date4(order+2:end), zeros(effectiveTex,1),'k:')
title('Exchange rate');
subplot(2,2,2);
plot(date1(order+2:end)', uratelower1', 'k--');
hold on
plot(date1(order+2:end)', urateupper1', 'k--');
hold on
x2 = [date1(order+2:end)', fliplr(date1(order+2:end)')];
inBetween = [urateupper2', fliplr(uratelower2')];
h=fill(x2, inBetween, [0.7 0.7 0.7]);
set(h,'EdgeColor','none');
hold on
plot(date1(order+2:end),urate,'k','LineWidth', 1.2)
hold on
plot(date1(order+2:end), zeros(effectiveT,1),'k:')
title('Unemployment');
subplot(2,2,3);
plot(date1(order+2:end)', debtlower1', 'k--');
hold on
plot(date1(order+2:end)', debtupper1', 'k--');
hold on
x2 = [date1(order+2:end)', fliplr(date1(order+2:end)')];
inBetween = [debtupper2', fliplr(debtlower2')];
h=fill(x2, inBetween, [0.7 0.7 0.7]);
set(h,'EdgeColor','none');
hold on
plot(date1(order+2:end),debt,'k','LineWidth', 1.2)
hold on
plot(date1(order+2:end), zeros(effectiveT,1),'k:')
title('Debt-to-GDP');
subplot(2,2,4);
plot(date1(order+2:end)', deficitlower1', 'k--');
hold on
plot(date1(order+2:end)', deficitupper1', 'k--');
hold on
x2 = [date1(order+2:end)', fliplr(date1(order+2:end)')];
inBetween = [deficitupper2', fliplr(deficitlower2')];
h=fill(x2, inBetween, [0.7 0.7 0.7]);
set(h,'EdgeColor','none');
hold on
plot(date1(order+2:end),deficit,'k','LineWidth', 1.2)
hold on
plot(date1(order+2:end), zeros(effectiveT,1),'k:')
title('Deficit-to-GDP');

