% ----------------------------------------------------
% COMMON SPECIFICATIONS
% ----------------------------------------------------
clear;clc;close all;
% ----------------------------------------------------
% FIG A5
% ----------------------------------------------------

% true parameters
A=[-0.1 -0.1;1.2 0.4];
C0=[1 0 ; -0.2  1];
A2=2*A;
C02=[1 0 ; -0.4  1];
iC0=inv(C0);
iC02=inv(C02);
trueirf1(:,:,1)=iC0;
trueirf2(:,:,1)=iC02;
for i=1:8
    trueirf1(:,:,i+1)=(iC0*A)^i*iC0;
    trueirf2(:,:,i+1)=(iC02*A2)^i*iC02;
end
true1=squeeze(trueirf1(2,1,:));
true2=squeeze(trueirf2(2,1,:));
it1=true1(1);
it2=true2(1);
at1=mean(true1(1:8));
at2=mean(true2(1:8));
disp('true impact responses (before and after param. change');
[it1 it2]
disp('true average responses (before and after param. change');
[at1 at2]
[true1 true2]

% simulate data, estimate with TVP
T=220;
breakpoint=70;
order=1;periods=10;K=size(A,2);
bandwidth=sqrt(T); 
SimulatedData=[];
imat=[];amat=[];
for counter=1:1000
    disp(counter);
    rng('shuffle');
    e=1.0056e-05*randn(T,2);
    data=zeros(1,size(e,2));
    for t=2:T
        if t<=breakpoint
            this=inv(C0)*A*data(t-1,:)'+inv(C0)*e(t,:)';
        elseif t>breakpoint && t<=2*breakpoint
            this=inv(C02)*A2*data(t-1,:)'+inv(C02)*e(t,:)';
        else
            this=inv(C0)*A*data(t-1,:)'+inv(C0)*e(t,:)';
        end
        data=[data;this'];
    end
    SimulatedData(:,:,counter)=data;
    [AA,IRF,Sigu,U,Pmat]=tvpvar(data,order,periods,bandwidth);
    mat=squeeze(IRF(:,2,:));
    impact=mat(1,:)';
    average=mean(mat(1:8,:))';
    imat=[imat impact];
    amat=[amat average];
end
   
itrue=[it1*ones(breakpoint,1) ; it2*ones(breakpoint,1) ; it1*ones(size(impact,1)-2*breakpoint,1)];
atrue=[at1*ones(breakpoint,1) ; at2*ones(breakpoint,1) ; at1*ones(size(impact,1)-2*breakpoint,1)];
isort=sort(imat,2);
asort=sort(amat,2);
med=asort(:,round(0.5*size(asort,2)));
low=asort(:,round(0.1*size(asort,2)));
high=asort(:,round(0.9*size(asort,2)));

% now estimate recursively from the same simulated data
bandwidth=2*sqrt(size(SimulatedData,1));
for counter=1:size(SimulatedData,3)
    disp(counter);
    data=SimulatedData(:,:,counter);
    for sampleend=50:size(data,1)
        usedata=data(1:sampleend,:);
        [AA,IRF,Sigu,U,Pmat]=tvpvar(usedata,order,periods,bandwidth);
        mat=squeeze(IRF(:,2,:));
        impact=mat(1,:)';
        average=mean(mat(1:8,:))';
        imatr(sampleend,counter)=impact(end);
        amatr(sampleend,counter)=average(end);
    end
end

isortr=sort(imatr,2);
asortr=sort(amatr,2);
figure;plot(itrue,'Linewidth',6);hold on;plot(isortr(:,round(0.1*size(isortr,2)):round(0.9*size(isortr,2))));title('impact, true and recursively estimated (inner 90%)');
figure;plot(atrue,'Linewidth',6);hold on;plot(asortr(:,round(0.1*size(asortr,2)):round(0.9*size(asortr,2))));title('average, true and recursively estimated (inner 90%)');

medr=asortr(:,round(0.5*size(asortr,2)));
medr(1:sum(medr==0))=nan;
lowr=asortr(:,round(0.1*size(asortr,2)));
lowr(1:sum(lowr==0))=nan;
highr=asortr(:,round(0.9*size(asortr,2)));
highr(1:sum(highr==0))=nan;

figure;
subplot(1,2,1);
    plot(atrue,'b-');
    hold on
    plot(low,'k--');
    hold on
    plot(high,'k--');
    hold on
    plot(med,'k:','Linewidth',2.2);
    axis([0 220 0.1 0.6])
    title('full-sample estimation');
subplot(1,2,2);
    plot(atrue,'b-');
    hold on
    plot(lowr,'k--');
    hold on
    plot(highr,'k--');
    hold on
    plot(medr,'k:','Linewidth',2.2);
    title('recursive estimation');
    axis([0 220 0.1 0.6])
    %xlabel('Sample used up to period T^* = ...');


