% ----------------------------------------------------
% COMMON SPECIFICATIONS
%-----------------------------------------------------
clear;clc;close all;
order=4;periods=10;cumperiod=8;
reps=100;
confidence1=0.90;
confidence2=0.68;

% ----------------------------------------------------
% Data
%-----------------------------------------------------
samplestart=1969;
[date1,rgdp,rgov,inflyp,sr2,bondsb,lrate2,taxy,cc,gdebt_gdp,unemp,recession,ffr,...
    rcons,rinv,infle,news,gf,pop]=getdata(samplestart);

data1=[dlog(rgov,1) dlog(rgdp,1) trimr(taxy,1,0) dlev(gdebt_gdp,1) ...
    trimr([inflyp infle sr2 bondsb-lrate2 cc./1000],1,0)];
    % check for missings
    if sum(sum(isnan(data1)))>0;error('missing observations, adjust sample!');end
    
bandwidth=sqrt(size(data1,1)); 
rposg=1;              %relative position of G-variable
rposy=2;              %relative position of Y-variable
rposinfl=5;           % inflation position
rposinfle=6;          % expected inflation

selvek=(size(data1,2)*(rposg-1)+1:size(data1,2)*rposg)';
effectiveT=size(data1,1)-order;

% point estimates
 [~,IRF,~]=tvpvar(data1,order,periods,bandwidth);
% bootstrap data
 [bsdatamat]=tvpvar_bs2(data1,order,bandwidth,reps); 
 
% ----------------------------------------------------
% EFFECT ON INFLATION AND EXPECTED INFLATION
%-----------------------------------------------------

% inflation:
convert_to_levels=0;
 [resp,resplower1,respupper1,resplower2,respupper2,impact,impactlower1,impactupper1,...
    impactlower2,impactupper2,average,averagelower1,averageupper1,averagelower2,averageupper2]=...
    get_impactaverage(IRF,bsdatamat,selvek,rposinfl,confidence1,confidence2,order,periods,bandwidth,...
    convert_to_levels,cumperiod);

infl=average;
infllower1=averagelower1;
influpper1=averageupper1;
infllower2=averagelower2;
influpper2=averageupper2;

% expected inflation
convert_to_levels=0;
 [resp,resplower1,respupper1,resplower2,respupper2,impact,impactlower1,impactupper1,impactlower2,impactupper2...
    average,averagelower1,averageupper1,averagelower2,averageupper2]=...
    get_impactaverage(IRF,bsdatamat,selvek,rposinfle,confidence1,confidence2,order,periods,bandwidth,...
    convert_to_levels,cumperiod);

einfl=average;
einfllower1=averagelower1;
einflupper1=averageupper1;
einfllower2=averagelower2;
einflupper2=averageupper2;

figure;
subplot(1,2,1);
plot(date1(order+2:end)', infllower1', 'k--');
hold on
plot(date1(order+2:end)', influpper1', 'k--');
hold on
x2 = [date1(order+2:end)', fliplr(date1(order+2:end)')];
inBetween = [influpper2', fliplr(infllower2')];
h=fill(x2, inBetween, [0.7 0.7 0.7]);
set(h,'EdgeColor','none');
hold on
plot(date1(order+2:end),infl,'k','LineWidth', 1.2)
hold on
plot(date1(order+2:end), zeros(effectiveT,1),'k:')
xlim([1968 2017]);
title('Inflation response, average');
subplot(1,2,2);
plot(date1(order+2:end)', einfllower1', 'k--');
hold on
plot(date1(order+2:end)', einflupper1', 'k--');
hold on
x2 = [date1(order+2:end)', fliplr(date1(order+2:end)')];
inBetween = [einflupper2', fliplr(einfllower2')];
h=fill(x2, inBetween, [0.7 0.7 0.7]);
set(h,'EdgeColor','none');
hold on
plot(date1(order+2:end),einfl,'k','LineWidth', 1.2)
hold on
plot(date1(order+2:end), zeros(effectiveT,1),'k:')
xlim([1968 2017]);
title('Expected inflation response, average');


% ----------------------------------------------------
% EFFECT ON IMPLIED SHORT REAL RATE (ex post vs ex ante)
%-----------------------------------------------------
 
% implied real ex post rate: shadow rate - realized inflation
rposint=7;            % interest rate position 
convert_to_levels=0;
 [realresp,realresplower1,realrespupper1,realresplower2,realrespupper2,impact,impactlower1,impactupper1,...
    impactlower2,impactupper2,average,averagelower1,averageupper1,averagelower2,averageupper2]=...
    get_realrate(IRF,bsdatamat,selvek,rposint,rposinfl,confidence1,confidence2,order,periods,bandwidth,...
    convert_to_levels,cumperiod);
real=average;
reallower1=averagelower1;
realupper1=averageupper1;
reallower2=averagelower2;
realupper2=averageupper2;
  
% implied real ex ante: shadow rate - expected inflation
rposint=7;            % interest rate position
convert_to_levels=0;
 [realresp,realresplower1,realrespupper1,realresplower2,realrespupper2,impact,impactlower1,impactupper1,...
    impactlower2,impactupper2,average,averagelower1,averageupper1,averagelower2,averageupper2]=...
    get_realrate(IRF,bsdatamat,selvek,rposint,rposinfle,confidence1,confidence2,order,periods,bandwidth,...
    convert_to_levels,cumperiod);
ereal=average;
ereallower1=averagelower1;
erealupper1=averageupper1;
ereallower2=averagelower2;
erealupper2=averageupper2;


figure;
subplot(1,2,1);
plot(date1(order+2:end)', reallower1', 'k--');
hold on
plot(date1(order+2:end)', realupper1', 'k--');
hold on
x2 = [date1(order+2:end)', fliplr(date1(order+2:end)')];
inBetween = [realupper2', fliplr(reallower2')];
h=fill(x2, inBetween, [0.7 0.7 0.7]);
set(h,'EdgeColor','none');
hold on
plot(date1(order+2:end),real,'k','LineWidth', 1.2)
hold on
plot(date1(order+2:end), zeros(effectiveT,1),'k:')
xlim([1968 2017]);
title('Ex-post real rate response, average');
subplot(1,2,2);
plot(date1(order+2:end)', ereallower1', 'k--');
hold on
plot(date1(order+2:end)', erealupper1', 'k--');
hold on
x2 = [date1(order+2:end)', fliplr(date1(order+2:end)')];
inBetween = [erealupper2', fliplr(ereallower2')];
h=fill(x2, inBetween, [0.7 0.7 0.7]);
set(h,'EdgeColor','none');
hold on
plot(date1(order+2:end),ereal,'k','LineWidth', 1.2)
hold on
plot(date1(order+2:end), zeros(effectiveT,1),'k:')
title('Ex-ante real rate response');
xlim([1968 2017]);


