function [coefs,phimat,u,irfs]=constantcoefficientsvar(data,order,periods)

k=size(data,2);T=size(data,1);
const=ones(T-order,1);
exogmat=const;

% estimate coefficients:
    [coefs,u]=getestimates(data,order,exogmat);
% generate VMA matrices (impulse responses)
    phimat=getphi(coefs,u,order,periods);
% generate recursively identified impulse responses to shocks of size 1
    sigu=(u'*u)/T;
    pmat=chol(sigu);pmat=pmat';      
    dmat=diag(diag(pmat),0);wmat=pmat*inv(dmat); % use wmat for irfs of one unit size
    irfs=[];
    for i=1:periods
        phi=phimat(:,:,i);phi_chol=phi*wmat;
        irfs=[irfs; phi_chol(:)'];  
    end
    
% END OF MAIN FUNCTION-----------------------------------------------------


% GETESTIMATES-------------------------------------------------------------
function [coefs,u]=getestimates(data,order,exogmat)
    k=size(data,2);
    rhs=exogmat;
    for j=1:order
        rhs=[rhs data(order+1-j:end-j,:)];
    end
    u=[];
    coefmat=[];
    for i=1:k
            lhs=data(order+1:end,i);
            thisb=(rhs'*rhs)\(rhs'*lhs);
            thisu=lhs-rhs*thisb;
            u=[u thisu];
            coefmat=[coefmat; thisb'];        
    end
    exogcoef=coefmat(:,1:size(exogmat,2));     %the coefficients of the exogs
    aa=coefmat(:,size(exogmat,2)+1:end);       %all other coefficients
    % reorganize aa as three dimensional array where sheet j is the 
    % matrix A_j with the coefficients pertaining to the j-th lag:
    coefs=zeros(k,k,order);
    for j=1:order
        coefs(:,:,j)=aa(:,j*k-k+1:j*k);
    end
end 
% END OF GETESTIMATES------------------------------------------------------


% GETPHI------------------------------------------------------------------
function phimat=getphi(coefs,u,order,periods)
    k=size(u,2);
    T=size(u,1);
    sigu=(u'*u)/(T-order);
    % compute phi-matrices of VMA representation which contain impulse
    % response coefficients
    phimat=zeros(k,k,periods);
    phimat(:,:,1)=eye(k);
    for i=1:periods
        for j=1:i-1
            if j<=order
               Aj=coefs(:,:,j);
            else
               Aj=zeros(k,k);
            end    
            phimat(:,:,i)=phimat(:,:,i)+Aj*phimat(:,:,i-j);
        end
    end
end
% END OF GETPHI-----------------------------------------------------------

end
