function [betasmoothed,Psmoothed]=kalmanhamilton_getsmoothed(betatt,Ptt,Q)
% returns the Kalman smoothed unobservable state beta_t|t and
% the sequence of smoothed MSE matrices P_t|t for the model
%
% y_t = x_t' beta_t + epsi_t
% beta_t = beta_t-1 + eta_t
%
% with a diagonal time invariant covariance matrix Q of eta and a scalar
% variance R of epsi
%
% inputs: betatt k x 1 x T array of filtered beta states (from kalmanhamilton_getfiltered.m)
%         Ptt    k x k x T array of filtered MSE matrices (from kalmanhamilton_getfiltered.m)
%         Q kxk diagonal covariance matrix of eta
%         
T=size(betatt,3);
k=size(betatt,1);
%  set terminal values 
betasmoothed=zeros(k,1,T);
Psmoothed=zeros(k,k,T);
betasmoothed(:,:,T) = betatt(:,:,T);
Psmoothed(:,:,T) = Ptt(:,:,T);
for it=1:(T-1)
       P0T = Psmoothed(:,:,T-it+1);
       beta0T = betasmoothed(:,:,T-it+1);
       Pfilt = Ptt(:,:,T-it);           %   this is P t given t 
       Pnext = Pfilt + Q;               %   this is P t+1 given t 
       Jt = Pfilt*inv(Pnext);
       P0T = Pfilt + Jt*(P0T - Pnext)*Jt';
	   beta0T = betatt(:,:,T-it) + Jt*(beta0T - betatt(:,:,T-it));
       betasmoothed(:,:,T-it) = beta0T;
       Psmoothed(:,:,T-it) = P0T;
end

end