function minusloglik=kalmanhamilton_loglik(coefs,y,X,betastart,Pstart)
%
% returns minus the loglikelihood of the model 
% y_t = x_t' beta_t + epsi_t
% beta_t = beta_t-1 + eta_t
% with a diagonal time invariant covariance matrix Q of eta and a scalar
% variance R of epsi
%
% inputs: y Tx1 vector 
%         X Txk matrix of predetermined regressors
%         betastart, Pstart are kx1 and kxk initializations for the parameter vector and the MSE matrix

T=size(y,1);
k=size(X,2);

Q=diag(coefs(1:k)); % diagonal covariance matrix of innovations to beta
R=coefs(k+1);       % scalar variance of epsilon, the model residual

beta10=betastart;
P10=Pstart;
L=0;
betatt=zeros(k,1,T);
Ptt=zeros(k,k,T);
for t=1:T
    yhat = X(t,:)*beta10;
    yvar = (X(t,:)*P10*X(t,:)' + R);
    yvarinv = inv(yvar);
    resid = y(t) - yhat;
    lnlt = -0.5*log(det(yvar)) - 0.5*resid'*yvarinv*resid;
    L=L+lnlt;
    beta11 = beta10 + P10*X(t,:)'*yvarinv*resid;
    betatt(:,:,t) = beta11;
    P11 = P10 - P10*X(t,:)'*yvarinv*X(t,:)*P10;
    Ptt(:,:,t) = P11;
    beta10 = beta11;
    P10 = P11 + Q;
end

minusloglik=-L;
end