function IRF=tvp_recvar_kalman(data,order,periods)

% recursive (triangular) VAR estimated with Kalman filter, ML estimated
% model is C0 data_t = const + C1 data_t-1 + ... Corder data_t-order + epsilon
% where C0 must be lower triangular with ones on the diagonal (standard recursive VAR)
%
% the constant is added automatically

tempols=@(y,X) ((X'*X)\(X'*y));

effectiveT=size(data,1)-order;
K=size(data,2);
laggedvariables=[];
for j=1:order
    laggedvariables=[laggedvariables data(order+1-j:end-j,:)];
end
tvcoefs=[];
for i=1:K              % loop over equations
    const=ones(size(data,1)-order,1);
    lhs=data(order+1:end,i);
    contemporaneous=data(order+1:end,1:i-1);
    rhs=[laggedvariables contemporaneous const];
    cpb=tempols(lhs,rhs);  % constant coefficients as starting values
    k=size(rhs,2);
    beta00=cpb;
    P00=eye(k);  
    start=1*ones(k+1,1);
    lb=ones(size(start))*0.000;ub=ones(size(start))*100; % variances must be positive
    result=fmincon(@(coefs) kalmanhamilton_loglik(coefs,lhs,rhs,beta00,P00),start,[],[],[],[],lb,ub,[]);
    Q=diag(result(1:k));  
    R=result(k+1);
    % Get the Kalman filtered unobserved state beta_t (recursive estimate based
    % on data through time t):
    [betatt,Ptt]=kalmanhamilton_getfiltered(lhs,rhs,Q,R,beta00,P00);
    % Get the Kalman smoothed unobserved state beta_t (full sample estimated
    % based on all data t=1,...,T):
    [betasmoothed,Psmoothed]=kalmanhamilton_getsmoothed(betatt,Ptt,Q);
    b=squeeze(betasmoothed)';
    tvcoefs{i}=b;
end

% -----------------------------------------------------------
% build the time varying C matrices by equation (i.e. by row)
% -----------------------------------------------------------
eC0=zeros(K,K,effectiveT);
C=zeros(K,K,order,effectiveT);
for i=1:K                        % loop over equations
    thesecoefs=tvcoefs{i};       % all coefs of equation i
    for t=1:effectiveT           % loop over time periods
        this=thesecoefs(t,:)';   % coefs of equation i at time t
        if i>=2
            eC0(i,1:i-1,t)=this(K*order+1:K*order+i-1); % build matrix I - C0
        end
        for j=1:order
            C(i,:,j,t)=this(j*K-K+1:j*K);
        end
    end
end
C0=eye(K)-eC0;

% -----------------------------------------------------------
% construct time varying impulse responses
% -----------------------------------------------------------
IRF=zeros(periods,K^2,effectiveT);
for t=1:effectiveT
    thisC0=C0(:,:,t);
    thisC=C(:,:,:,t);
    ithisC0=inv(thisC0);
    psimat=zeros(K,K,periods);
    psimat(:,:,1)=ithisC0;
    thisirf=[];
    for i=1:periods
        for j=1:i-1
            if j<=order
               Bj=ithisC0*thisC(:,:,j);
            else
               Bj=zeros(K,K);
            end    
            psimat(:,:,i)=psimat(:,:,i)+Bj*psimat(:,:,i-j);
        end
        temp=psimat(:,:,i);
        thisirf=[thisirf;temp(:)'];
    end
    IRF(:,:,t)=thisirf;
end

end