function [AA,IRF,Sigu,U,Pmat]=tvpvar(data,order,periods,bandwidth)

T=size(data,1);
K=size(data,2);
H=bandwidth;
effectiveT=T-order;

% set up matrices following the notation in KL eq 2.3.1
yt=data(order+1:end,:);
Z1=[];                % Z1 contains all lagged variables
for t=order+1:T
    Zt1=1;
    for j=1:order
        Zt1= [Zt1; data(t-j,:)' ];
    end
    Z1= [Z1;Zt1'];
end

% reduced form parameter estimation
% for each t in AA(:,:,t) the estimated parameters are organized as in A
% above, i.e. first column constants, column 2:K+1 lag1-coefs, 
% column K+2:2K+1 lag2-coefs etc.
AA=[];U=[];
for t=1:effectiveT
    sum1=0;sum2=0;
    for j=1:effectiveT
        ktj=(1/sqrt(2*pi))*exp((-((t-j)/H)^2)/2);
        sum1=sum1+ktj*yt(j,:)'*Z1(j,:);
        sum2=sum2+ktj*Z1(j,:)'*Z1(j,:);
    end
    thisA=sum1*inv(sum2);
    AA(:,:,t)=thisA;
    thisu=yt(t,:)'-thisA*Z1(t,:)';
    U=[U; thisu'];          % residuals
end

% covariance matrices of residuals
% for each t in Sigu(:,:,t) the time varying covariance matrix is stored
% in Pmat for each t in Pmat(:,:,t) the Cholesky decomposition is stored
Sigu= [];Pmat=[];
for t=1:effectiveT
    sum1=0;sum2=0;
    for j=1:effectiveT
        ktj=(1/sqrt(2*pi))*exp((-((t-j)/H)^2)/2);
        sum1=sum1+ktj*U(j,:)'*U(j,:);
        sum2=sum2+ktj;
    end
    thissigu=sum1/sum2;
    Sigu(:,:,t)=thissigu;
    thispmat=chol(thissigu)';
    Pmat(:,:,t)=thispmat;
end

% impulse responses, for each time period
IRF=zeros(periods,K^2,effectiveT);
for t=1:effectiveT
    thisA=AA(:,2:end,t);       % the constants in the first column are cut off
    phimat=zeros(K,K,periods); % the reduced form IRFs
    phimat(:,:,1)=eye(K);
    for i=1:periods
            for j=1:i-1
                if j<=order
                   Aj=thisA(:,j*K-K+1:j*K);
                else
                   Aj=zeros(K,K);
                end    
                phimat(:,:,i)=phimat(:,:,i)+Aj*phimat(:,:,i-j);
            end
    end
    thispmat=Pmat(:,:,t);                        % use thispmat for irfs of one s.d. size
    thisdmat=diag(diag(thispmat),0);thiswmat=thispmat*inv(thisdmat); % use thiswmat for irfs of one unit size
    irf_chol=[];
    for i=1:size(phimat,3)
        phi=phimat(:,:,i);phi_chol=phi*thiswmat;irf_chol=[irf_chol; phi_chol(:)'];  
    end
    IRF(:,:,t)=irf_chol;
end

end