function [bsdatamat]=tvpvar_bs2(data,order,bandwidth,reps)

     H=bandwidth;

    % estimate time varying parameters (reduced form)
      [AA,U]=getestimates(data,order,H);
      
    % generate boostrap data samples (T,K,reps)
      bsdatamat=getbootstrapdata(data,U,AA,order,reps);
      
end
% -------------------------------------- END OF MAIN FUNCTION

% ---------------------------------------- BEGIN GETESTIMATES 
function [AA,U]=getestimates(data,order,H)
    T=size(data,1);effectiveT=T-order;
    % reduced form parameter estimation
    % set up matrices following the notation in KL eq 2.3.1
    Z1=[];                % Z1 contains all lagged variables
    for t=order+1:T
        Zt1=1;
        for j=1:order
            Zt1= [Zt1; data(t-j,:)' ];
        end
        Z1= [Z1;Zt1'];
    end
    yt=data(order+1:end,:);

    % for each t in AA(:,:,t) the estimated parameters are organized as follows:
    % the first column contains constants, column 2:K+1 lag1-coefs, 
    % column K+2:2K+1 lag2-coefs etc.
    AA=[];U=[];
    for t=1:effectiveT
        sum1=0;sum2=0;
        for j=1:effectiveT
            ktj=(1/sqrt(2*pi))*exp((-((t-j)/H)^2)/2);
            sum1=sum1+ktj*yt(j,:)'*Z1(j,:);
            sum2=sum2+ktj*Z1(j,:)'*Z1(j,:);
        end
        thisA=sum1*inv(sum2);
        AA(:,:,t)=thisA;
        thisu=yt(t,:)'-thisA*Z1(t,:)';
        U=[U; thisu'];          % residuals
    end
end % of getestimates()
% ---------------------------------------- END GETESTIMATES 

% ---------------------------------------- BEGIN GETBOOTSTRAPDATA 
function bsdatamat=getbootstrapdata(data,U,AA,order,reps)
    T=size(data,1);K=size(data,2);
    % generate bootstrapped data samples
    bsdatamat=zeros(T,K,reps);
    for counter=1:reps
        % reshuffle residuals:
         bsindx=randi(size(U,1),size(U,1),1);
         bsU=U(bsindx,:);
         % initial values set to zero:
         bsU=[zeros(order,size(bsU,2)) ;bsU];
         % construct a simulated data set bsdata
         bsdata=zeros(T,K);
         bsdata(1:order,:)=data(1:order,:);  % initialize with actual data
         for t=order+1:T
             thisA=AA(:,2:end,t-order);    % the lag coefficients
             bsdata(t,:)=AA(:,1,t-order)';  % the constants
             for i=1:order
                thisAi=thisA(:,i*K-K+1:i*K); 
                bsdata(t,:)=bsdata(t,:)+(thisAi*bsdata(t-i,:)')';
             end           
             bsdata(t,:)=bsdata(t,:)+bsU(t,:);
         end   
         % collect simulated data in a matrix to be returned:
         bsdatamat(:,:,counter)=bsdata;
    end
end % of getbootstrapdata()
% ---------------------------------------- END GETBOOTSTRAPDATA 

